NestedFrame

Struct NestedFrame 

pub struct NestedFrame<'a, 'b, A>
where A: AtomBody + ?Sized,
{ /* private fields */ }
A writing frame managing nested atoms.

Unlike the RootFrame, which really manages memory, this frame only forwards writing calls to the next frame in the hierarchy and updates the atom header accordingly. Additionally, this frame will assure for padding when dropped. These padding bytes will not be included in the top level header, only in the surrounding ones.

Nested frames can only be created with the create_nested_frame method.