RootFrame

Struct RootFrame 

pub struct RootFrame<'a, A: AtomBody + ?Sized> { /* private fields */ }
The ground level writing frame.

This writing frame manages the first atom and actually has access to the data. It is created by the AtomOutputPort and simply acts like any WritingFrame.

Implementations

Source

impl<'a, A: AtomBody + ?Sized> RootFrame<'a, A>

pub fn new(free_space: &'a mut [u8], urids: &mut CachedMap) -> Result<Self, ()>

Try to create a new root frame.

All you need to create a root frame is a slice of writable memory and a way to retrieve the URID of the managed atom. Then, this function will initialize the header in the beginning of the slice and create the frame.

If the slice is not big enough to hold the atom header, this function returns an Err.