ObjectWritingFrame

Trait ObjectWritingFrame 

pub trait ObjectWritingFrame<'a>: WritingFrame<'a> + WritingFrameExt<'a, Object> {
    // Provided method
    fn push_property<'b, A: AtomBody + ?Sized>(
        &'b mut self,
        key: URID,
        context: URID,
        parameter: &A::InitializationParameter,
        urids: &mut CachedMap,
    ) -> Result<NestedFrame<'b, 'a, A>, ()> { ... }
}
Extension for WritingFrame and WritingFrameExt for vectors.

See the module documentation for more information.

Provided Methods

fn push_property<'b, A: AtomBody + ?Sized>( &'b mut self, key: URID, context: URID, parameter: &A::InitializationParameter, urids: &mut CachedMap, ) -> Result<NestedFrame<'b, 'a, A>, ()>

Add a property to the object.

The key and the context are the same as in the PropertyHeader: The key represents the name of the property and the context’s purpose is unknown and should be set to zero.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<'a, W> ObjectWritingFrame<'a> for W
where W: WritingFrame<'a> + WritingFrameExt<'a, Object>,