VectorWritingFrame

Trait VectorWritingFrame 

pub trait VectorWritingFrame<'a, T>
where T: 'static + AtomBody + Sized + Copy, Self: WritingFrame<'a> + WritingFrameExt<'a, Vector<T>>,
{ // Provided methods fn push(&mut self, value: T) -> Result<(), ()> { ... } fn append(&mut self, slice: &[T]) -> Result<(), ()> { ... } }
Extension for WritingFrame and WritingFrameExt for vectors.

See the module documentation for more information.

Provided Methods

fn push(&mut self, value: T) -> Result<(), ()>

Push a value to the end of the vector.

fn append(&mut self, slice: &[T]) -> Result<(), ()>

Append a slice of values to the end of the vector.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<'a, T, F> VectorWritingFrame<'a, T> for F
where T: 'static + AtomBody + Sized + Copy, F: WritingFrame<'a> + WritingFrameExt<'a, Vector<T>>,