Vector

Type Alias Vector 

pub type Vector<T> = ArrayAtomBody<VectorHeader, T>;
A homogenous array of sized atoms.

See the module documentation for more information.

Aliased Type

#[repr(C)]
pub struct Vector<T> { pub header: VectorHeader, pub data: [T], }

Fields

header: VectorHeaderdata: [T]

Implementations

Source

impl<T> Vector<T>
where T: 'static + AtomBody + Sized + Copy,

pub fn child_body_size(&self) -> usize

Return the size of the child type, according to the vector’s body header.

pub fn child_body_type(&self) -> URID

Return the type of the child, according to the vector’s body header.

pub fn as_slice(&self) -> &[T]

Return a slice containing all items in the vector.

No allocation is done; This method simply borrows the data of the vector.