pub type Vector<T> = ArrayAtomBody<VectorHeader, T>;Expand description
A homogenous array of sized atoms.
See the module documentation for more information.
Aliased Type
#[repr(C)]pub struct Vector<T> {
pub header: VectorHeader,
pub data: [T],
}Fields
header: VectorHeaderdata: [T]Implementations
Sourceimpl<T> Vector<T>
impl<T> Vector<T>
Sourcepub fn child_body_size(&self) -> usize
pub fn child_body_size(&self) -> usize
Return the size of the child type, according to the vector’s body header.
Sourcepub fn child_body_type(&self) -> URID
pub fn child_body_type(&self) -> URID
Return the type of the child, according to the vector’s body header.